@@ -92,7 +92,7 @@ fast_theo_mu_sig <- function(wei_sp_mat, n1, n2) {
 
 fast.permu_edge <- function(n_per, wei_sp_mat, n1, n2, progress_bar = FALSE) {
     n <- n1 + n2
-    if (progress_bar && interactive()) {
+    if (progress_bar && is_interactive()) {
         pb <- txtProgressBar(min = 0, max = n_per, initial = 0)
         temp <- sapply(1:n_per, function(peri) {
             setTxtProgressBar(pb, peri)
@@ -319,7 +319,7 @@ pathway.rgTest <- function(
         # pb <- progress::progress_bar$new(format = "[:bar] :percent ETA: :eta")
         # res <- furrr::future_map(idx.list, test_fun, .progress = TRUE, .options = furrr_options(seed = TRUE))
 
-        if (interactive()) {
+        if (is_interactive()) {
             pb <- progress::progress_bar$new(format = "[:bar] :percent ETA: :eta")
             res <- furrr::future_map(idx.list, test_fun, .progress = TRUE, .options = furrr_options(seed = TRUE))
         } else {
@@ -330,7 +330,7 @@ pathway.rgTest <- function(
     } else {
         # res <- t(pbapply::pbsapply(idx.list, test_fun))
 
-        if (interactive()) {
+        if (is_interactive()) {
             res <- t(pbapply::pbsapply(idx.list, test_fun))
         } else {
             res <- t(sapply(idx.list, test_fun))
@@ -340,11 +340,17 @@ pathway.rgTest <- function(
     res <- cbind(res, gene.set.length = l.gene.set)
 
     p.adj <- apply(res[, paste0("asy.", unlist(test.type), ".pval"), drop = FALSE], 2, p.adjust, method = "fdr")
+    if (is.null(dim(p.adj))) {
+        p.adj <- matrix(p.adj, ncol = length(test.type))
+    }
     colnames(p.adj) <- paste0("asy.", unlist(test.type), ".pval.adj")
     res <- as.data.frame(cbind(res, p.adj))
 
     if (perm.num > 0) {
         p.adj <- apply(res[, paste0("perm.", unlist(test.type), ".pval"), drop = FALSE], 2, p.adjust, method = "fdr")
+        if (is.null(dim(p.adj))) {
+            p.adj <- matrix(p.adj, ncol = length(test.type))
+        }
         colnames(p.adj) <- paste0("perm.", unlist(test.type), ".pval.adj")
         res <- as.data.frame(cbind(res, p.adj))
     }
