@@ -50,7 +50,7 @@ add.gene.embedding <- function(
     }
 
     X_data <- as.matrix(Seurat::GetAssayData(
-        object = seu, slot = "data", assay = assay
+        object = seu, layer = "data", assay = assay
     ))
 
     cellsCoordinates <- Seurat::Embeddings(seu, reduction.name)
@@ -102,7 +102,7 @@ add.gene.embedding <- function(
 #' pos <- toydata$pos
 #' 
 #' adjm <- ProFAST::AddAdj(as.matrix(pos), radius.upper = 200)
-#' X <- Seurat::GetAssayData(object = seu, slot = "data", assay = "RNA")
+#' X <- Seurat::GetAssayData(object = seu, layer = "data", assay = "RNA")
 #' cellembedding <- cellembedding_matrix(
 #'     X = X,
 #'     adjm = adjm
@@ -179,7 +179,7 @@ cellembedding_seurat <- function(
     # Start timing the process
     tstart <- Sys.time()
 
-    X_all <- Seurat::GetAssayData(object = seu, slot = slot, assay = assay)
+    X_all <- Seurat::GetAssayData(object = seu, layer = slot, assay = assay)
 
     var.fe.tmp <- get_varfeature_fromSeurat(seu, assay = assay)
     if (is.null(var.features)) {
